//===----------------------------------------------------------------------===//
// Copyright © 2026 Apple Inc. and the container project authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//===----------------------------------------------------------------------===//

public enum SandboxKeys: String {
    /// ID key.
    case id
    /// Vsock port number key.
    case port
    /// Exit code for a process
    case exitCode
    /// Exit timestamp for a process
    case exitedAt
    /// FD to a container resource key.
    case fd
    /// Options for stopping a container key.
    case stopOptions
    /// An endpoint to talk to a sandbox service.
    case sandboxServiceEndpoint

    /// Process request keys.
    case signal
    case snapshot
    case stdin
    case stdout
    case stderr
    case width
    case height
    case processConfig

    /// Container statistics
    case statistics

    /// Network resource keys.
    case allocatedAttachments
    case networkAdditionalData
    case networkAttachment
    case networkPluginInfo
}
